==> Gtk2-Perl-0.04.tar.gz: Gtk2-Perl-0.04/Gtk2/include/gtk2-perl-helpers-pango-autogen.h <==
#define SvPangoAttr(o) ((PangoAttr*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoAttr"))))
#define SvPangoAttr_nullok(o) (SvROK(o) ? ((PangoAttr*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoAttr")))) : NULL)
#define SvPangoFontFamily(o) ((PangoFontFamily*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontFamily"))))
#define SvPangoFontFamily_nullok(o) (SvROK(o) ? ((PangoFontFamily*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontFamily")))) : NULL)
#define SvPangoFontFace(o) ((PangoFontFace*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontFace"))))
#define SvPangoFontFace_nullok(o) (SvROK(o) ? ((PangoFontFace*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontFace")))) : NULL)
#define SvPangoFont(o) ((PangoFont*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFont"))))
#define SvPangoFont_nullok(o) (SvROK(o) ? ((PangoFont*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFont")))) : NULL)
#define SvPangoFontMap(o) ((PangoFontMap*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontMap"))))
#define SvPangoFontMap_nullok(o) (SvROK(o) ? ((PangoFontMap*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontMap")))) : NULL)
#define SvPangoFontset(o) ((PangoFontset*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontset"))))
#define SvPangoFontset_nullok(o) (SvROK(o) ? ((PangoFontset*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontset")))) : NULL)
#define SvPangoFontDescription(o) ((PangoFontDescription*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontDescription"))))
#define SvPangoFontDescription_nullok(o) (SvROK(o) ? ((PangoFontDescription*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontDescription")))) : NULL)
#define SvPangoFontMetrics(o) ((PangoFontMetrics*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontMetrics"))))
#define SvPangoFontMetrics_nullok(o) (SvROK(o) ? ((PangoFontMetrics*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontMetrics")))) : NULL)
#define SvPangoContext(o) ((PangoContext*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoContext"))))
#define SvPangoContext_nullok(o) (SvROK(o) ? ((PangoContext*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoContext")))) : NULL)
#define SvPangoLanguage(o) ((PangoLanguage*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoLanguage"))))
#define SvPangoLanguage_nullok(o) (SvROK(o) ? ((PangoLanguage*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoLanguage")))) : NULL)
#define SvPangoLayout(o) ((PangoLayout*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoLayout"))))
#define SvPangoLayout_nullok(o) (SvROK(o) ? ((PangoLayout*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoLayout")))) : NULL)
#define SvPangoAttrList(o) ((PangoAttrList*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoAttrList"))))
#define SvPangoAttrList_nullok(o) (SvROK(o) ? ((PangoAttrList*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoAttrList")))) : NULL)
#define SvPangoAlignment(o) gtk2_perl_convert_enum(PANGO_TYPE_ALIGNMENT, o)
#define newSVPangoAlignment(o) gtk2_perl_convert_back_enum(PANGO_TYPE_ALIGNMENT, o)
#define SvPangoDirection(o) gtk2_perl_convert_enum(PANGO_TYPE_DIRECTION, o)
#define newSVPangoDirection(o) gtk2_perl_convert_back_enum(PANGO_TYPE_DIRECTION, o)
#define SvPangoWrapMode(o) gtk2_perl_convert_enum(PANGO_TYPE_WRAP_MODE, o)
#define newSVPangoWrapMode(o) gtk2_perl_convert_back_enum(PANGO_TYPE_WRAP_MODE, o)

==> Gtk2-Perl-0.12.tar.gz: Gtk2-Perl-0.12/Gtk2/include/gtk2-perl-helpers-pango-autogen.h <==
#define SvPangoAttr(o) ((PangoAttr*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoAttr"))))
#define SvPangoAttr_nullok(o) (SvROK(o) ? ((PangoAttr*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoAttr")))) : NULL)
#define SvPangoFontFamily(o) ((PangoFontFamily*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontFamily"))))
#define SvPangoFontFamily_nullok(o) (SvROK(o) ? ((PangoFontFamily*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontFamily")))) : NULL)
#define SvPangoFontFace(o) ((PangoFontFace*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontFace"))))
#define SvPangoFontFace_nullok(o) (SvROK(o) ? ((PangoFontFace*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontFace")))) : NULL)
#define SvPangoFont(o) ((PangoFont*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFont"))))
#define SvPangoFont_nullok(o) (SvROK(o) ? ((PangoFont*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFont")))) : NULL)
#define SvPangoFontMap(o) ((PangoFontMap*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontMap"))))
#define SvPangoFontMap_nullok(o) (SvROK(o) ? ((PangoFontMap*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontMap")))) : NULL)
#define SvPangoFontset(o) ((PangoFontset*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontset"))))
#define SvPangoFontset_nullok(o) (SvROK(o) ? ((PangoFontset*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontset")))) : NULL)
#define SvPangoFontDescription(o) ((PangoFontDescription*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontDescription"))))
#define SvPangoFontDescription_nullok(o) (SvROK(o) ? ((PangoFontDescription*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontDescription")))) : NULL)
#define SvPangoFontMetrics(o) ((PangoFontMetrics*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontMetrics"))))
#define SvPangoFontMetrics_nullok(o) (SvROK(o) ? ((PangoFontMetrics*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoFontMetrics")))) : NULL)
#define SvPangoContext(o) ((PangoContext*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoContext"))))
#define SvPangoContext_nullok(o) (SvROK(o) ? ((PangoContext*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoContext")))) : NULL)
#define SvPangoLanguage(o) ((PangoLanguage*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoLanguage"))))
#define SvPangoLanguage_nullok(o) (SvROK(o) ? ((PangoLanguage*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoLanguage")))) : NULL)
#define SvPangoLayout(o) ((PangoLayout*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoLayout"))))
#define SvPangoLayout_nullok(o) (SvROK(o) ? ((PangoLayout*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoLayout")))) : NULL)
#define SvPangoAttribute(o) ((PangoAttribute*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoAttribute"))))
#define SvPangoAttribute_nullok(o) (SvROK(o) ? ((PangoAttribute*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoAttribute")))) : NULL)
#define SvPangoAttrList(o) ((PangoAttrList*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoAttrList"))))
#define SvPangoAttrList_nullok(o) (SvROK(o) ? ((PangoAttrList*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoAttrList")))) : NULL)
#define SvPangoRectangle(o) ((PangoRectangle*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoRectangle"))))
#define SvPangoRectangle_nullok(o) (SvROK(o) ? ((PangoRectangle*) SvIV(SvRV(gtk2_perl_check_type(o, "PangoRectangle")))) : NULL)
#define SvPangoStretch(o) gtk2_perl_convert_enum(PANGO_TYPE_STRETCH, o)
#define newSVPangoStretch(o) gtk2_perl_convert_back_enum(PANGO_TYPE_STRETCH, o)
#define SvPangoStyle(o) gtk2_perl_convert_enum(PANGO_TYPE_STYLE, o)
#define newSVPangoStyle(o) gtk2_perl_convert_back_enum(PANGO_TYPE_STYLE, o)
#define SvPangoAlignment(o) gtk2_perl_convert_enum(PANGO_TYPE_ALIGNMENT, o)
#define newSVPangoAlignment(o) gtk2_perl_convert_back_enum(PANGO_TYPE_ALIGNMENT, o)
#define SvPangoDirection(o) gtk2_perl_convert_enum(PANGO_TYPE_DIRECTION, o)
#define newSVPangoDirection(o) gtk2_perl_convert_back_enum(PANGO_TYPE_DIRECTION, o)
#define SvPangoVariant(o) gtk2_perl_convert_enum(PANGO_TYPE_VARIANT, o)
#define newSVPangoVariant(o) gtk2_perl_convert_back_enum(PANGO_TYPE_VARIANT, o)
#define SvPangoUnderline(o) gtk2_perl_convert_enum(PANGO_TYPE_UNDERLINE, o)
#define newSVPangoUnderline(o) gtk2_perl_convert_back_enum(PANGO_TYPE_UNDERLINE, o)
#define SvPangoWrapMode(o) gtk2_perl_convert_enum(PANGO_TYPE_WRAP_MODE, o)
#define newSVPangoWrapMode(o) gtk2_perl_convert_back_enum(PANGO_TYPE_WRAP_MODE, o)
